@@ -1253,12 +1253,16 @@ nextgen:
       }
    }
 
-   /* set the new bounding box */
+   /* Set the new bounding box.  In pathological cases, such as a page	*/
+   /* with only pin labels, the bounds may not have been changed from	*/
+   /* their initial values.  If so, then don't touch the bounding box.	*/
 
-   thisobj->bbox.lowerleft.x = llx;
-   thisobj->bbox.lowerleft.y = lly;
-   thisobj->bbox.width = urx - llx;
-   thisobj->bbox.height = ury - lly;
+   if ((llx < urx) && (lly < ury)) {
+      thisobj->bbox.lowerleft.x = llx;
+      thisobj->bbox.lowerleft.y = lly;
+      thisobj->bbox.width = urx - llx;
+      thisobj->bbox.height = ury - lly;
+   }
 
    /* calculate instance-specific values */
    calcbboxinst(thisinst);
@@ -1303,8 +1307,10 @@ void centerview(objinstptr tinst)
 void refresh(xcWidget bw, caddr_t clientdata, caddr_t calldata)
 {
    drawarea(NULL, NULL, NULL);
-   drawhbar(areastruct.scrollbarh, NULL, NULL);
-   drawvbar(areastruct.scrollbarv, NULL, NULL);
+   if (areastruct.scrollbarh)
+      drawhbar(areastruct.scrollbarh, NULL, NULL);
+   if (areastruct.scrollbarv)
+      drawvbar(areastruct.scrollbarv, NULL, NULL);
    printname(topobject);
 }
 
