@@ -273,7 +273,7 @@ extern char *nosprint(char *);
 extern Boolean xc_tilde_expand(char *);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
-extern void writelabelsegs(FILE *, short *, stringpart *);
+extern int writelabelsegs(FILE *, short *, stringpart *);
 extern void printobjects(FILE *, objectptr, objectptr **, short *, int);
 extern void printrefobjects(FILE *, objectptr, objectptr **, short *);
 extern void printpageobject(FILE *, objectptr, short, short);
@@ -686,6 +686,7 @@ extern Boolean render_client();
 
 /* from schema.c: */
 
+extern objectptr NameToPageObject(char *, objinstptr *);
 extern objectptr NameToObject(char *, objinstptr *, Boolean);
 extern void callwritenet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
